# Sigma Tools

This package contains the following tools for [Sigma](https://github.com/SigmaHQ/sigma):

* `sigmac`: the Sigma converter
* `merge_sigma`: Merge a Sigma collection into a minimal set of Sigma rules
* `sigma2misp`: Import Sigma rules into MISP
* `sigma2attack`: Create a MITRE ATT&CK® coverage map
* `sigma_similarity`: Measure similarity of Sigma rules
* `sigma_uuid`: Check Sigma identifiers
